## To install the package run

$ pip install opencti-excel-uploader

## To use the package

In your terminal run

$ opencti-excel-uploader /path/to/your/folder

If this is your first time running the package, you will be prompted to enter your OpenCTI URL, API token, Author first and last name, Author email ad Marking Definition.

This information will be saved in a configuration file in your directory.

The package will return workbench files for you to manually validate on opencti's workbench.
